@@ -32,6 +32,7 @@
 #
 # End Of Comments
 # --------------------------------------------------------------------------- #
+# modify for pyobd by emme750
 
 
 """Description:
@@ -150,6 +151,8 @@ SM_DRAW_MIDDLE_TEXT = 128
 SM_DRAW_MIDDLE_ICON = 256
 SM_DRAW_GRADIENT = 512
 SM_DRAW_FANCY_TICKS = 1024
+SM_DRAW_TITLE_TEXT = 2048
+SM_DRAW_SUB_TEXT = 4096
 
 #----------------------------------------------------------------------
 # Event Binding
@@ -385,6 +388,10 @@ class SpeedMeter(BufferedWindow):
         self.SetSecondGradientColour()
         self.SetHandStyle()
         self.DrawExternalArc()
+
+        self.SetTitleText()
+        self.SetSubText()
+
         
         BufferedWindow.__init__(self, parent, id, pos, size,
                                 style=wx.NO_FULL_REPAINT_ON_RESIZE,
@@ -889,6 +896,43 @@ class SpeedMeter(BufferedWindow):
             dc.SetTextForeground(middlecolour)
             dc.DrawText(middletext, newx, newy)
 
+        if self._extrastyle & SM_DRAW_TITLE_TEXT:
+
+            middlecolour = self.GetMiddleTextColour()            
+            titletext = self.GetTitleText()
+            #middleangle = (startangle + endangle)/2.0
+            
+            middlefont, middlesize = self.GetMiddleTextFont()
+            middlesize = self.scale*middlesize*0.8
+            middlefont.SetPointSize(int(middlesize))
+            dc.SetFont(middlefont)
+
+            mw, mh, dummy, dummy = dc.GetFullTextExtent(titletext, middlefont)
+            
+            #newx = centerX + 1.5*mw*cos(middleangle) - mw/2.0
+            #newy = centerY - 1.5*mh*sin(middleangle) - mh/2.0
+            dc.SetTextForeground(middlecolour)
+            dc.DrawText(titletext, 0, 30)
+
+        if self._extrastyle & SM_DRAW_SUB_TEXT:
+
+            middlecolour = self.GetMiddleTextColour()            
+            subtext = self.GetSubText()
+            #middleangle = (startangle + endangle)/2.0
+            
+            middlefont, middlesize = self.GetMiddleTextFont()
+            middlesize = self.scale*middlesize*0.7
+            middlefont.SetPointSize(int(middlesize))
+            dc.SetFont(middlefont)
+
+            mw, mh, dummy, dummy = dc.GetFullTextExtent(titletext, middlefont)
+            
+            #newx = centerX + 1.5*mw*cos(middleangle) - mw/2.0
+            #newy = centerY - 1.5*mh*sin(middleangle) - mh/2.0
+            dc.SetTextForeground(middlecolour)
+            dc.DrawText(subtext, 0, 120)
+
+
         # Here We Draw The Icon In The Middle, Near The Start Of The Arrow (If Present)
         # This Is Like The "Fuel" Icon In The Cars                
         if self._extrastyle & SM_DRAW_MIDDLE_ICON:
@@ -1292,11 +1336,36 @@ class SpeedMeter(BufferedWindow):
         self._middletext = text
 
 
+    def SetTitleText(self, text=None):
+        """ Sets The Text To Be Drawn Near The Center Of SpeedMeter. """
+        
+        if text is None:
+            text = ""
+
+        self._tiletext = text
+
+    def SetSubText(self, text=None):
+        """ Sets The Text To Be Drawn Near The Center Of SpeedMeter. """
+        
+        if text is None:
+            text = ""
+
+        self._subtext = text
+
     def GetMiddleText(self):
         """ Gets The Text To Be Drawn Near The Center Of SpeedMeter. """
         
         return self._middletext
 
+    def GetTitleText(self):
+        
+        return self._tiletext
+
+    def GetSubText(self):
+        
+        return self._subtext
+
+
 
     def SetMiddleTextFont(self, font=None):
         """ Sets The Font For The Text In The Middle."""
@@ -1515,6 +1584,14 @@ class SpeedMeter(BufferedWindow):
         if self._extrastyle & SM_DRAW_MIDDLE_TEXT:
             stringstyle.append("SM_DRAW_MIDDLE_TEXT")
             integerstyle.append(SM_DRAW_MIDDLE_TEXT)
+
+        if self._extrastyle & SM_DRAW_TITLE_TEXT:
+            stringstyle.append("SM_DRAW_TITLE_TEXT")
+            integerstyle.append(SM_DRAW_TITLE_TEXT)
+
+        if self._extrastyle & SM_DRAW_SUB_TEXT:
+            stringstyle.append("SM_DRAW_SUB_TEXT")
+            integerstyle.append(SM_DRAW_SUB_TEXT)
         
         if self._extrastyle & SM_DRAW_MIDDLE_ICON:
             stringstyle.append("SM_DRAW_MIDDLE_ICON")
