@@ -125,18 +125,30 @@ class TestEvent(wx.PyEvent):
 # Define notification event for dial result window
 EVT_DIAL_ID = 1004
 class DialEvent(wx.PyEvent):
-   """Simple event to carry arbitrary result data."""
+
    def __init__(self, data):
        """Init Dial Event."""
        wx.PyEvent.__init__(self)
        self.SetEventType(EVT_DIAL_ID)
        self.data = data
+
+EVT_DIAL1_ID = 1005
+
+class DialEvent1(wx.PyEvent):
+
+   def __init__(self, data):
+       """Init Dial1 Event."""
+       wx.PyEvent.__init__(self)
+       self.SetEventType(EVT_DIAL1_ID)
+       self.data = data
+
        
 #defines notification event for debug tracewindow
 from debugEvent import *
        
 class MyApp(wx.App):
     # A listctrl which auto-resizes the column boxes to fill
+
     class MyListCtrl(wx.ListCtrl, ListCtrlAutoWidthMixin):
         def __init__(self, parent, id, pos = wx.DefaultPosition, size = wx.DefaultSize, style = 0):
 
@@ -157,7 +169,6 @@ class MyApp(wx.App):
             self._nb=_nb
             threading.Thread.__init__ ( self )
 
-
         def initCommunication(self):
 
             #print self.portName
@@ -197,7 +208,8 @@ class MyApp(wx.App):
         
 
         def run(self):
-            global btname
+            global btname, maxbar
+            maxbar=0
 
             wx.PostEvent(self._notify_window, StatusEvent([0,1,"Connecting...."]))
             try:
@@ -336,8 +348,26 @@ class MyApp(wx.App):
 				s = self.port.sensor(speedsensor)
 				text="rpm"+str(s[1])
 				wx.PostEvent(self._notify_window, DialEvent(text))
+			wx.Yield()
+
+		elif curstate==5:
+
+			speedsensor=11
+
+			if self.active[speedsensor]:
+				s = self.port.sensor(speedsensor)
+				text=str(s[1])
+				l=len(text)
+				n=0
+				while n<(l-1):
+					if str(text[n]) == '#' :
+						text=text[0:n]
+						break
+					n=n+1
+				wx.PostEvent(self._notify_window, DialEvent1(text))
 			wx.Yield()                   
 
+
                 else:
                  pass 
             self.stop()
@@ -608,7 +638,87 @@ class MyApp(wx.App):
         ####################################################################
 
         self.nb.AddPage(Dialpanel, "Gauges")
+##########
+    def build_dial_page1(self):
 
+        HOFFSET_LIST=0 #offset from the top of panel (space for buttons)
+        Dialpanel1 = wx.Panel(self.nb, -1)
+        self.Dialpanel1=Dialpanel1
+        tID = wx.NewId()
+        self.dial_id = tID
+
+        # Third SpeedMeter: We Use The Following Styles:
+        #
+        # SM_DRAW_HAND: We Want To Draw The Hand (Arrow) Indicator
+
+        # SM_DRAW_PARTIAL_SECTORS: Partial Sectors Will Be Drawn, To Indicate Different Intervals
+        # SM_DRAW_MIDDLE_ICON: We Draw An Icon In The Center Of SpeedMeter
+        
+        self.SpeedWindow3 = SM.SpeedMeter(Dialpanel1,
+                                          extrastyle=SM.SM_DRAW_HAND |
+                                          SM.SM_DRAW_PARTIAL_SECTORS |
+                                          SM.SM_DRAW_MIDDLE_TEXT |
+                                          SM.SM_DRAW_TITLE_TEXT |
+                                          SM.SM_DRAW_SUB_TEXT
+                                          )
+ 
+        # We Want To Simulate A Car Gas-Control
+        self.SpeedWindow3.SetAngleRange(-pi/3, pi/3)
+
+        intervals = range(0,5)
+        self.SpeedWindow3.SetIntervals(intervals)
+
+        colours = [wx.RED]*1
+        colours.append('#FFFF00')
+        colours.append(wx.BLACK)
+        colours.append(wx.BLACK)
+
+        self.SpeedWindow3.SetIntervalColours(colours)
+
+        ticks = ["", "3", "2", "1", ""]
+        self.SpeedWindow3.SetTicks(ticks)
+        self.SpeedWindow3.SetTicksColour(wx.WHITE)
+        self.SpeedWindow3.SetTicksFont(wx.Font(10, wx.SCRIPT, wx.NORMAL, wx.BOLD, True))
+        self.SpeedWindow3.SetMiddleText("bar")
+        self.SpeedWindow3.SetMiddleTextColour(wx.WHITE)
+        self.SpeedWindow3.SetMiddleTextFont(wx.Font(14, wx.SWISS, wx.NORMAL, wx.BOLD))
+
+        self.SpeedWindow3.SetHandColour(wx.Colour(255, 255, 0))
+
+        self.SpeedWindow3.SetTitleText("MAP\n(intake manifold absolute pressure)") #
+        self.SpeedWindow3.SetSubText("Max: ") #
+
+        # Draw The Icon In The Center Of SpeedMeter        
+        #self.SpeedWindow3.SetMiddleIcon(icon)        
+
+        self.SpeedWindow3.SetSpeedBackground(wx.BLACK)        
+
+        self.SpeedWindow3.SetArcColour(wx.WHITE)
+        
+        self.SpeedWindow3.SetSpeedValue(0)
+
+        
+
+        ####################################################################
+        # This little bit of magic keeps the list the same size as the frame
+        def OnPSize(e, win = Dialpanel1):
+            Dialpanel1.SetSize(e.GetSize())
+            self.SpeedWindow3.SetSize(e.GetSize())
+
+            w,h = self.frame.GetClientSizeTuple()
+#            self.SpeedWindow3.SetDimensions(0,0, w/2.2 ,h-25 )
+            self.SpeedWindow3.SetDimensions(0,0, w+200 ,h-25 )
+
+
+
+        Dialpanel1.Bind(wx.EVT_SIZE,OnPSize)
+        ####################################################################
+
+        self.nb.AddPage(Dialpanel1, "Turbo")
+
+
+
+#########
        
     def TraceDebug(self,level,msg):
         if self.DEBUGLEVEL<=level:
@@ -688,6 +798,7 @@ class MyApp(wx.App):
         EVT_RESULT(self,self.OnDebug, EVT_DEBUG_ID)
         EVT_RESULT(self,self.OnDtc,EVT_DTC_ID)
         EVT_RESULT(self,self.OnDial,EVT_DIAL_ID)
+        EVT_RESULT(self,self.OnDial1,EVT_DIAL1_ID)
         EVT_RESULT(self,self.OnStatus,EVT_STATUS_ID)
         EVT_RESULT(self,self.OnTests,EVT_TESTS_ID)
         
@@ -719,6 +830,7 @@ class MyApp(wx.App):
 
         self.build_DTC_page()
         self.build_dial_page()
+        self.build_dial_page1()
         
         self.trace = self.MyListCtrl(self.nb, tID,style=wx.LC_REPORT|wx.SUNKEN_BORDER)
         self.trace.InsertColumn(0, "Level",width=70)
@@ -818,7 +930,7 @@ class MyApp(wx.App):
         stringa = 'dbus-send --print-reply --dest=com.nokia.osso_notes /com/nokia/osso_notes com.nokia.osso_notes.mime_open string:/home/opt/pyobd/pyobd.txt'
         os.popen(stringa)
 
-        Text = """ pyobd-0.9.2-19
+        Text = """ pyobd-0.9.2-20
 
 Adapted to n900 by m750 at maemo.org
 """
@@ -889,7 +1001,7 @@ later version.
 
 
     def OnDial(self,event):
-	#print "k: " + str(self.k)
+	print "k: " + str(self.k)
 	wx.Yield()
 	data=event.data
 	d1=data[:3]
@@ -921,6 +1033,20 @@ later version.
 
 		self.SpeedWindow5.SetSpeedValue(d2)
 
+    def OnDial1(self,event):
+	global maxbar
+	data=event.data
+	#print data
+	d1=int(data)/100.0
+	d2=4-d1
+	#print d1
+	#print d2
+	self.SpeedWindow3.SetSpeedValue(d2)
+	wx.Yield()
+	if d1>maxbar:
+		maxbar=d1
+		self.SpeedWindow3.SetSubText("Max: "+str(d1))
+	wx.Yield()
 
     def OnDisconnect(self,event): #disconnect connection to ECU
         global btaddr, seriale, node, manager, bus, adapter, target_address , service, path
